@@ -44,6 +44,12 @@ class JobResult:
             if member.isfile():
                 yield member.name, self._tar.extractfile(member)
 
+    @property
+    def documents(self) -> Iterator[Tuple[str, BinaryIO]]:
+        for file_name, file in self.files:
+            if file_name not in ["out.log", "job.json"]:
+                yield file_name, file
+
     @property
     def log(self) -> Iterator[dict]:
         for fn, fp in self.files:
